summaryrefslogtreecommitdiff
path: root/jstests/replsets/capped_id.js
diff options
context:
space:
mode:
authorKaloian Manassiev <kaloian.manassiev@mongodb.com>2015-11-25 11:20:43 -0500
committerKaloian Manassiev <kaloian.manassiev@mongodb.com>2015-12-08 13:05:00 -0500
commit3ed6635a5fb26c354046d275a1217c4526b2fe02 (patch)
treef40aa20b5e62996843ce3df0f47b82042dd683a7 /jstests/replsets/capped_id.js
parent4f24dc58f48cb087db8a4832421d298e9e2633a0 (diff)
downloadmongo-3ed6635a5fb26c354046d275a1217c4526b2fe02.tar.gz
SERVER-21050 Cleanup ReplSetTest
This is just a cleanup work to hide some of the private state of ReplSetTest so it is easier to encapsulate and add new logic. Also enables strict mode.
Diffstat (limited to 'jstests/replsets/capped_id.js')
-rw-r--r--jstests/replsets/capped_id.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/jstests/replsets/capped_id.js b/jstests/replsets/capped_id.js
index cd866fb0234..83942f6405f 100644
--- a/jstests/replsets/capped_id.js
+++ b/jstests/replsets/capped_id.js
@@ -18,9 +18,9 @@ var nodes = replTest.startSet();
// This will wait for initiation
replTest.initiate();
// Call getMaster to return a reference to the node that's been
// elected master
-var master = replTest.getMaster();
+var master = replTest.getPrimary();
// wait for secondaries to be up, since we'll be reading from them
replTest.awaitSecondaryNodes();
@@ -28,7 +28,7 @@ replTest.awaitSecondaryNodes();
var slave1 = replTest.liveNodes.slaves[0];
var slave2 = replTest.liveNodes.slaves[1];
// Calling getMaster made available the liveNodes structure,
// which looks like this:
// liveNodes = {master: masterNode, slaves: [slave1, slave2] }
printjson( replTest.liveNodes );
@@ -18,9 +18,9 @@ var nodes = replTest.startSet();
// This will wait for initiation
replTest.initiate();
-// Call getMaster to return a reference to the node that's been
+// Call getPrimary to return a reference to the node that's been
// elected master
@@ -28,7 +28,7 @@ replTest.awaitSecondaryNodes();
var slave1 = replTest.liveNodes.slaves[0];
var slave2 = replTest.liveNodes.slaves[1];
-// Calling getMaster made available the liveNodes structure,
+// Calling getPrimary made available the liveNodes structure,
// which looks like this:
// liveNodes = {master: masterNode, slaves: [slave1, slave2] }